import {ComponentFixture, fakeAsync, flush, TestBed} from '@angular/core/testing';

import { ActivityModalComponent } from './activity-modal.component';
import {FormGroup, FormGroupDirective, FormsModule, ReactiveFormsModule} from '@angular/forms';
import {AngularMaterialModule} from '../../modules/angular-material.module';
import {BrowserAnimationsModule} from '@angular/platform-browser/animations';
import {Component, Input} from '@angular/core';
import {DataSourceService} from '../../services/data-source.service';
import {CarePlan} from '@nspop/gm-web-facade-api';
import {Subject} from 'rxjs';

describe('ActivityModalComponent', () => {
  let component: ActivityModalComponent;
  let fixture: ComponentFixture<ActivityModalComponent>;
  let carePlanSubjectStub: Subject<CarePlan>;
  let dataSourceServiceStub: DataSourceService;
  @Component({selector: 'app-modal', template: '<div><ng-content></ng-content></div>'})
  class ModalComponent {
    @Input() public header = '';
    private isModalVisible = false;
    public setVisible(isVisible: boolean): void {
      this.isModalVisible = isVisible;
    }
  }
  beforeEach(async () => {
    carePlanSubjectStub = new Subject<CarePlan>();
    dataSourceServiceStub = {
      carePlan$: carePlanSubjectStub.asObservable(),
      updateCarePlan: () => carePlanSubjectStub.asObservable(),
      refresh: () => {},
    } as any;

    await TestBed.configureTestingModule({
      declarations: [ ActivityModalComponent, ModalComponent],
      imports: [
        ReactiveFormsModule,
        FormsModule,
        ReactiveFormsModule,
        AngularMaterialModule,
        BrowserAnimationsModule,
      ],
      providers: [
        {provide: DataSourceService, useValue: dataSourceServiceStub},
      ]
    })
    .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(ActivityModalComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  it('should hide the dialog upon submission', fakeAsync(() => {
    const mockFormDirective = new FormGroupDirective([], []);
    spyOn(mockFormDirective, 'resetForm');
    component.setVisible(true);
    expect(component.isVisible()).toBeTrue();
    const mockForm = new FormGroup({});
    component.submitActivity(mockForm, mockFormDirective);
    carePlanSubjectStub.next({} as any);
    flush();
    expect(component.isVisible()).toBeFalse();
  }));
});
