import { Injectable } from '@angular/core';
import {ApiService} from './api.service';
import {HttpClient} from '@angular/common/http';
import {Observable} from 'rxjs';
import {
  CreateUltrasoundObservationsRequest,
  ObservationTable,
  CreateRegularObservationsRequest,
  ScanningObservationTable,
} from '@nspop/gm-web-facade-api';
import {apiUrls} from '../../utils/URL_STRING_LITERALS';

@Injectable({
  providedIn: 'root'
})
export class ObservationService extends ApiService {

  constructor(httpClient: HttpClient) {
    super(apiUrls.observation, httpClient);
  }

  createUltrasoundObservations(observations: CreateUltrasoundObservationsRequest): Observable<void> {
    return this.extendUrlAndCall('/scan', () => super.create(observations));
  }

  createRegularObservations(observations: CreateRegularObservationsRequest): Observable<void> {
    return this.extendUrlAndCall('/regular', () => super.create(observations));
  }

  getUltrasoundObservationTable(): Observable<ScanningObservationTable> {
    return this.extendUrlAndCall('/table/scan', () => super.getAll());
  }

  getClinicalObservationTable(): Observable<ObservationTable> {
    return this.extendUrlAndCall('/table/clinical', () => super.getAll());
  }
}
